<?php

/**
 * @file
 * Contains Drupal\itchio_field\Plugin\Field\FieldFormatter\ItchioIframeFormatter.
 */

namespace Drupal\itchio_field\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;

/**
 * Plugin implementation of the 'itchio_formatter' formatter.
 *
 * @FieldFormatter(
 *   id = "itchio_formatter",
 *   module = "itchio_field",
 *   label = @Translation("Simple text-based formatter"),
 *   field_types = {
 *     "itchio_field_itchio"
 *   }
 * )
 */
class ItchioIframeFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = array();

    foreach ($items as $delta => $item) {
      $value = !empty($item->value) ? $item->value : '';
      $linkback = isset($item->linkback) ? $item->linkback : 0;
      $borderwidth = isset($item->borderwidth) ? $item->borderwidth : '';
      $bg_color = isset($item->bg_color) ? $item->bg_color : '';
      $fg_color = isset($item->fg_color) ? $item->fg_color : '';
      $link_color = isset($item->link_color) ? $item->link_color : '';
      $border_color = isset($item->border_color) ? $item->border_color : '';
      $width = isset($item->width) ? $item->width : '';
      $height = isset($item->height) ? $item->height : '';
      
      $src = 'https://itch.io/embed/' . $value . '?';
      if (!empty($linkback)) {
        $src .= 'linkback=true&';
      }
      $src .= 'border_width=' . $borderwidth . '&';
      $src .= 'bg_color=' . $bg_color . '&';
      $src .= 'fg_color=' . $fg_color . '&';
      $src .= 'border_color=' . $border_color;

      $elements[$delta] = array(
        '#type' => 'html_tag',
        '#tag' => 'iframe',
        '#attributes' => array(
          'src' => $src,
          'width' => $width,
          'height' => $height,
          'frameborder' => 0
        ),
        '#value' => '',
      );
    }

    return $elements;
  }

}
