<?php

/**
 * @file
 * Contains Drupal\itchio_field\Plugin\Field\FieldType\ItchioItem.
 */

namespace Drupal\itchio_field\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Plugin implementation of the 'itchio_field_itchio' field type.
 *
 * @FieldType(
 *   id = "itchio_field_itchio",
 *   label = @Translation("Itchio Field"),
 *   module = "itchio_field",
 *   description = @Translation("A field for an itch project number"),
 *   default_widget = "itchio_iframe",
 *   default_formatter = "itchio_formatter"
 * )
 */
class ItchioItem extends FieldItemBase {
  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    return array(
      'columns' => array(
        'value' => array(
          'type' => 'int',
          'size' => 'normal',
          'unsigned' => TRUE,
          'not null' => FALSE,
        ),
        'linkback' => array(
          'type' => 'int',
          'not null' => FALSE,
          'default' => 0,
        ),
        'borderwidth' => array(
          'type' => 'int',
          'not null' => FALSE,
          'default' => 0,
        ),
        'bg_color' => array(
          'type' => 'varchar',
          'length' => 6,
          'not null' => TRUE,
          'default' => 'c9c9c9',
        ),
        'fg_color' => array(
          'type' => 'varchar',
          'length' => 6,
          'not null' => TRUE,
          'default' => '000000',
        ),
        'link_color' => array(
          'type' => 'varchar',
          'length' => 6,
          'not null' => TRUE,
          'default' => '0b628e',
        ),
        'border_color' => array(
          'type' => 'varchar',
          'length' => 6,
          'not null' => TRUE,
          'default' => 'a0a0a0',
        ),
        'width' => array(
          'type' => 'int',
          'not null' => TRUE,
          'default' => 552,
        ),
        'height' => array(
          'type' => 'int',
          'not null' => TRUE,
          'default' => 167,
        ),
      ),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    $value = $this->get('value')->getValue();
    $linkback = $this->get('linkback')->getValue();
    $borderwidth = $this->get('borderwidth')->getValue();
    $bg_color = $this->get('bg_color')->getValue();
    $fg_color = $this->get('fg_color')->getValue();
    $link_color = $this->get('link_color')->getValue();
    $border_color = $this->get('border_color')->getValue();
    $width = $this->get('width')->getValue();
    $height = $this->get('height')->getValue();

    if (empty($value) && empty($linkback) && empty($borderwidth) && empty($bg_color) && empty($fg_color) && empty($link_color) && empty($border_color) && empty($width) && empty($height)) {
      return TRUE;
    }

    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties['value'] = DataDefinition::create('string')
      ->setLabel(t('Itch project number'));
    $properties['linkback'] = DataDefinition::create('boolean')
      ->setLabel(t('Include link to itch.io page'));
    $properties['borderwidth'] = DataDefinition::create('integer')
      ->setLabel(t('Border Width'));
    $properties['bg_color'] = DataDefinition::create('string')
      ->setLabel(t('Background color'));
    $properties['fg_color'] = DataDefinition::create('string')
      ->setLabel(t('Foreground color'));
    $properties['link_color'] = DataDefinition::create('string')
      ->setLabel(t('Link color'));
    $properties['border_color'] = DataDefinition::create('string')
      ->setLabel(t('Border color'));
    $properties['width'] = DataDefinition::create('string')
      ->setLabel(t('Width'));
    $properties['height'] = DataDefinition::create('string')
      ->setLabel(t('Height'));

    return $properties;
  }

}
