<?php

/**
 * @file
 * Contains \Drupal\itchio_field\Plugin\Field\FieldWidget\ItchioIframeWidget.
 */

namespace Drupal\itchio_field\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'itchio_iframe' widget.
 *
 * @FieldWidget(
 *   id = "itchio_iframe",
 *   module = "itchio_field",
 *   label = @Translation("Itch.io iframe"),
 *   field_types = {
 *     "itchio_field_itchio"
 *   }
 * )
 */
class ItchioIframeWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $value = isset($items[$delta]->value) ? $items[$delta]->value : '';

    $value = isset($items[$delta]->value) ? $items[$delta]->value : '';
    $linkback = isset($items[$delta]->linkback) ? $items[$delta]->linkback : '';
    $borderwidth = isset($items[$delta]->borderwidth) ? $items[$delta]->borderwidth : '';
    $bg_color = isset($items[$delta]->bg_color) ? $items[$delta]->bg_color : '';
    $fg_color = isset($items[$delta]->fg_color) ? $items[$delta]->fg_color : '';
    $link_color = isset($items[$delta]->link_color) ? $items[$delta]->link_color : '';
    $border_color = isset($items[$delta]->border_color) ? $items[$delta]->border_color : '';
    $width = isset($items[$delta]->width) ? $items[$delta]->width : '';
    $height = isset($items[$delta]->height) ? $items[$delta]->height : '';

    $element['value'] = array(
      '#type' => 'textfield',
      '#title' => t('Itchio Project Number'),
      '#description' => t('Your game\'s project number on Itch.io. This is the last value of the url on your game\'s edit page - i.e. http://itch.io/game/edit/XXXXX'),
      '#default_value' => $value,
    );
    $element['linkback'] = array(
      '#type' => 'checkbox',
      '#title' => t('Include link to itch.io page'),
      '#default_value' => $linkback,
    );
    $element['borderwidth'] = array(
      '#type' => 'number',
      '#title' => t('Border width'),
      '#default_value' => $borderwidth,
      '#size' => 1,
    );
    $element['bg_color'] = array(
      '#type' => 'textfield',
      '#title' => t('Background color'),
      '#default_value' => $bg_color,
      '#size' => 6,
    );
    $element['fg_color'] = array(
      '#type' => 'textfield',
      '#title' => t('Foreground color'),
      '#default_value' => $fg_color,
      '#size' => 6,
    );
    $element['link_color'] = array(
      '#type' => 'textfield',
      '#title' => t('Link color'),
      '#default_value' => $link_color,
      '#size' => 6,
    );
    $element['border_color'] = array(
      '#type' => 'textfield',
      '#title' => t('Border color'),
      '#default_value' => $border_color,
      '#size' => 6,
    );
    $element['width'] = array(
      '#type' => 'number',
      '#title' => t('Width'),
      '#default_value' => $width,
      '#size' => 4,
    );
    $element['height'] = array(
      '#type' => 'number',
      '#title' => t('Height'),
      '#default_value' => $height,
      '#size' => 4,
    );

    // If cardinality is 1, ensure a label is output for the field by wrapping
    // it in a details element.
    if ($this->fieldDefinition->getFieldStorageDefinition()->getCardinality() == 1) {
      $element += array(
        '#type' => 'fieldset',
        '#attributes' => array('class' => array('container-inline')),
      );
    }

    return $element;
//
//    $element += array(
//      '#type' => 'textfield',
//      '#default_value' => $value,
//      '#size' => 20,
//      '#maxlength' => 20,
//
//      '#element_validate' => array(
//        array($this, 'validate'),
//      ),
//    );
//    return array('value' => $element);
  }

  /**
   * Validate the project text field.
   */
  public function validate($element, FormStateInterface $form_state) {
    $value = $element['#value'];
    if (strlen($value) == 0) {
      $form_state->setValueForElement($element, '');
      return;
    }
    if (intval($value) == 0) {
      $form_state->setError($element, t("Itch project number must be an integer"));
    }
  }

}
